@@ -1,19 +1,17 @@
 # Import calls and globalvariable calls
 
-#' @importFrom caret upSample downSample
 #' @importFrom grDevices adjustcolor rainbow rgb
 #' @importFrom graphics abline boxplot legend lines par plot points segments text matplot title axis mtext barplot hist strwidth polygon
+#' @importFrom plyr ddply
 #' @importFrom quantmod getSymbols
 #' @importFrom Rfast colmeans rowmeans rowsums comb_n
 #' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density hat qnorm model.matrix fivenum acf qt ecdf time approx embed frequency is.ts runif start ts optim quantile optimize dnorm dlnorm dexp dt t.test wilcox.test .preformat.ts var poly
-#' @importFrom stringr str_count
 #' @importFrom utils globalVariables head tail combn flush.console
 #' @importFrom xts to.monthly
 #' @importFrom zoo as.yearmon index
 #' @import data.table
 #' @import doParallel
 #' @import foreach
-#' @import meboot
 #' @rawNamespace import(Rcpp, except = LdFlags)
 #' @import RcppParallel
 #' @import rgl
@@ -42,7 +40,6 @@
   requireNamespace("data.table")
   requireNamespace("doParallel")
   requireNamespace("foreach")
-  requireNamespace("meboot")
   requireNamespace("Rcpp")
   requireNamespace("RcppParallel")
   requireNamespace("rgl")
